==> jc-1.4.0.tar.gz: gnu/java/net/PlainSocketImpl__24SocketOutputStream.h <==
// final class gnu.java.net.PlainSocketImpl$SocketOutputStream

// class file dependencies
// @dep_class aa4520938e33220f gnu_java_net_PlainSocketImpl__24SocketOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_gnu_java_net_PlainSocketImpl__24SocketOutputStream_H_
#define _JC_gnu_java_net_PlainSocketImpl__24SocketOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainSocketImpl$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_refs	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_nonrefs	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$refs	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$refs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$nonrefs	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object;

typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vmethods	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtable	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtable;
typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method$_init$24fc9fa1db57e8f4(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, struct _jc_gnu_java_net_PlainSocketImpl$object *);

// Virtual methods
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *);
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, jint);
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, jint);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vmethods	gnu_java_net_PlainSocketImpl__24SocketOutputStream;
};

// Vtype
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_refs {
	struct _jc_gnu_java_net_PlainSocketImpl$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$refs {
    _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_refs	gnu_java_net_PlainSocketImpl__24SocketOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_nonrefs	gnu_java_net_PlainSocketImpl__24SocketOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object {
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype	*vtype;
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_PlainSocketImpl__24SocketOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$class_object;

#endif	/* _JC_gnu_java_net_PlainSocketImpl__24SocketOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/PlainSocketImpl__24SocketOutputStream.h <==
// final class gnu.java.net.PlainSocketImpl$SocketOutputStream

// class file dependencies
// @dep_class f2231be91303dbdf gnu_java_net_PlainSocketImpl__24SocketOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_OutputStream

#include "java/io/OutputStream.h"

#ifndef _JC_gnu_java_net_PlainSocketImpl__24SocketOutputStream_H_
#define _JC_gnu_java_net_PlainSocketImpl__24SocketOutputStream_H_

// Forward structure declarations
struct _jc_gnu_java_net_PlainSocketImpl$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_refs	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_nonrefs	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$refs	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$refs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$nonrefs	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object;

typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vmethods	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtable	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtable;
typedef const struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype;

// Constructors
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method$_init$24fc9fa1db57e8f4(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, struct _jc_gnu_java_net_PlainSocketImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$method_info$write$306a698343ec27e8;

// Virtual methods structure
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vmethods	gnu_java_net_PlainSocketImpl__24SocketOutputStream;
};

// Vtype
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_refs {
	struct _jc_gnu_java_net_PlainSocketImpl$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$refs {
    _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_refs	gnu_java_net_PlainSocketImpl__24SocketOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$sub_nonrefs	gnu_java_net_PlainSocketImpl__24SocketOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$object {
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype	*vtype;
	_jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$vtype _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_PlainSocketImpl__24SocketOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_PlainSocketImpl__24SocketOutputStream$class_object;

#endif	/* _JC_gnu_java_net_PlainSocketImpl__24SocketOutputStream_H_ */
